==> chaosmesh-model-5.0.3-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/StressChaosSpecFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.StringBuffer;
import java.lang.Object;

public class StressChaosSpecFluentImpl<A extends StressChaosSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements StressChaosSpecFluent<A> {

    private String containerName;
    private String duration;
    private String mode;
    private SchedulerSpecBuilder scheduler;
    private SelectorSpecBuilder selector;
    private String stressngStressors;
    private StressorsBuilder stressors;
    private String value;

    public StressChaosSpecFluentImpl() {
    }

    public StressChaosSpecFluentImpl(StressChaosSpec instance) {
        this.withContainerName(instance.getContainerName()); 
        this.withDuration(instance.getDuration()); 
        this.withMode(instance.getMode()); 
        this.withScheduler(instance.getScheduler()); 
        this.withSelector(instance.getSelector()); 
        this.withStressngStressors(instance.getStressngStressors()); 
        this.withStressors(instance.getStressors()); 
        this.withValue(instance.getValue()); 
    }

    public String getContainerName() {
        return this.containerName;
    }

    public A withContainerName(String containerName) {
        this.containerName=containerName; return (A) this;
    }

    public Boolean hasContainerName() {
        return this.containerName != null;
    }

    public A withNewContainerName(String arg1) {
        return (A)withContainerName(new String(arg1));
    }

    public A withNewContainerName(StringBuilder arg1) {
        return (A)withContainerName(new String(arg1));
    }

    public A withNewContainerName(StringBuffer arg1) {
        return (A)withContainerName(new String(arg1));
    }

    public String getDuration() {
        return this.duration;
    }

    public A withDuration(String duration) {
        this.duration=duration; return (A) this;
    }

    public Boolean hasDuration() {
        return this.duration != null;
    }

    public A withNewDuration(String arg1) {
        return (A)withDuration(new String(arg1));
    }

    public A withNewDuration(StringBuilder arg1) {
        return (A)withDuration(new String(arg1));
    }

    public A withNewDuration(StringBuffer arg1) {
        return (A)withDuration(new String(arg1));
    }

    public String getMode() {
        return this.mode;
    }

    public A withMode(String mode) {
        this.mode=mode; return (A) this;
    }

    public Boolean hasMode() {
        return this.mode != null;
    }

    public A withNewMode(String arg1) {
        return (A)withMode(new String(arg1));
    }

    public A withNewMode(StringBuilder arg1) {
        return (A)withMode(new String(arg1));
    }

    public A withNewMode(StringBuffer arg1) {
        return (A)withMode(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildScheduler instead.
 * @return The buildable object.
 */
@Deprecated public SchedulerSpec getScheduler() {
        return this.scheduler!=null?this.scheduler.build():null;
    }

    public SchedulerSpec buildScheduler() {
        return this.scheduler!=null?this.scheduler.build():null;
    }

    public A withScheduler(SchedulerSpec scheduler) {
        _visitables.get("scheduler").remove(this.scheduler);
        if (scheduler!=null){ this.scheduler= new SchedulerSpecBuilder(scheduler); _visitables.get("scheduler").add(this.scheduler);} return (A) this;
    }

    public Boolean hasScheduler() {
        return this.scheduler != null;
    }

    public A withNewScheduler(String cron) {
        return (A)withScheduler(new SchedulerSpec(cron));
    }

    public StressChaosSpecFluent.SchedulerNested<A> withNewScheduler() {
        return new SchedulerNestedImpl();
    }

    public StressChaosSpecFluent.SchedulerNested<A> withNewSchedulerLike(SchedulerSpec item) {
        return new SchedulerNestedImpl(item);
    }

    public StressChaosSpecFluent.SchedulerNested<A> editScheduler() {
        return withNewSchedulerLike(getScheduler());
    }

    public StressChaosSpecFluent.SchedulerNested<A> editOrNewScheduler() {
        return withNewSchedulerLike(getScheduler() != null ? getScheduler(): new SchedulerSpecBuilder().build());
    }

    public StressChaosSpecFluent.SchedulerNested<A> editOrNewSchedulerLike(SchedulerSpec item) {
        return withNewSchedulerLike(getScheduler() != null ? getScheduler(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSelector instead.
 * @return The buildable object.
 */
@Deprecated public SelectorSpec getSelector() {
        return this.selector!=null?this.selector.build():null;
    }

    public SelectorSpec buildSelector() {
        return this.selector!=null?this.selector.build():null;
    }

    public A withSelector(SelectorSpec selector) {
        _visitables.get("selector").remove(this.selector);
        if (selector!=null){ this.selector= new SelectorSpecBuilder(selector); _visitables.get("selector").add(this.selector);} return (A) this;
    }

    public Boolean hasSelector() {
        return this.selector != null;
    }

    public StressChaosSpecFluent.SelectorNested<A> withNewSelector() {
        return new SelectorNestedImpl();
    }

    public StressChaosSpecFluent.SelectorNested<A> withNewSelectorLike(SelectorSpec item) {
        return new SelectorNestedImpl(item);
    }

    public StressChaosSpecFluent.SelectorNested<A> editSelector() {
        return withNewSelectorLike(getSelector());
    }

    public StressChaosSpecFluent.SelectorNested<A> editOrNewSelector() {
        return withNewSelectorLike(getSelector() != null ? getSelector(): new SelectorSpecBuilder().build());
    }

    public StressChaosSpecFluent.SelectorNested<A> editOrNewSelectorLike(SelectorSpec item) {
        return withNewSelectorLike(getSelector() != null ? getSelector(): item);
    }

    public String getStressngStressors() {
        return this.stressngStressors;
    }

    public A withStressngStressors(String stressngStressors) {
        this.stressngStressors=stressngStressors; return (A) this;
    }

    public Boolean hasStressngStressors() {
        return this.stressngStressors != null;
    }

    public A withNewStressngStressors(String arg1) {
        return (A)withStressngStressors(new String(arg1));
    }

    public A withNewStressngStressors(StringBuilder arg1) {
        return (A)withStressngStressors(new String(arg1));
    }

    public A withNewStressngStressors(StringBuffer arg1) {
        return (A)withStressngStressors(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildStressors instead.
 * @return The buildable object.
 */
@Deprecated public Stressors getStressors() {
        return this.stressors!=null?this.stressors.build():null;
    }

    public Stressors buildStressors() {
        return this.stressors!=null?this.stressors.build():null;
    }

    public A withStressors(Stressors stressors) {
        _visitables.get("stressors").remove(this.stressors);
        if (stressors!=null){ this.stressors= new StressorsBuilder(stressors); _visitables.get("stressors").add(this.stressors);} return (A) this;
    }

    public Boolean hasStressors() {
        return this.stressors != null;
    }

    public StressChaosSpecFluent.StressorsNested<A> withNewStressors() {
        return new StressorsNestedImpl();
    }

    public StressChaosSpecFluent.StressorsNested<A> withNewStressorsLike(Stressors item) {
        return new StressorsNestedImpl(item);
    }

    public StressChaosSpecFluent.StressorsNested<A> editStressors() {
        return withNewStressorsLike(getStressors());
    }

    public StressChaosSpecFluent.StressorsNested<A> editOrNewStressors() {
        return withNewStressorsLike(getStressors() != null ? getStressors(): new StressorsBuilder().build());
    }

    public StressChaosSpecFluent.StressorsNested<A> editOrNewStressorsLike(Stressors item) {
        return withNewStressorsLike(getStressors() != null ? getStressors(): item);
    }

    public String getValue() {
        return this.value;
    }

    public A withValue(String value) {
        this.value=value; return (A) this;
    }

    public Boolean hasValue() {
        return this.value != null;
    }

    public A withNewValue(String arg1) {
        return (A)withValue(new String(arg1));
    }

    public A withNewValue(StringBuilder arg1) {
        return (A)withValue(new String(arg1));
    }

    public A withNewValue(StringBuffer arg1) {
        return (A)withValue(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        StressChaosSpecFluentImpl that = (StressChaosSpecFluentImpl) o;
        if (containerName != null ? !containerName.equals(that.containerName) :that.containerName != null) return false;
        if (duration != null ? !duration.equals(that.duration) :that.duration != null) return false;
        if (mode != null ? !mode.equals(that.mode) :that.mode != null) return false;
        if (scheduler != null ? !scheduler.equals(that.scheduler) :that.scheduler != null) return false;
        if (selector != null ? !selector.equals(that.selector) :that.selector != null) return false;
        if (stressngStressors != null ? !stressngStressors.equals(that.stressngStressors) :that.stressngStressors != null) return false;
        if (stressors != null ? !stressors.equals(that.stressors) :that.stressors != null) return false;
        if (value != null ? !value.equals(that.value) :that.value != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(containerName,  duration,  mode,  scheduler,  selector,  stressngStressors,  stressors,  value,  super.hashCode());
    }

    public class SchedulerNestedImpl<N> extends SchedulerSpecFluentImpl<StressChaosSpecFluent.SchedulerNested<N>> implements StressChaosSpecFluent.SchedulerNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final SchedulerSpecBuilder builder;

            SchedulerNestedImpl(SchedulerSpec item) {
                this.builder = new SchedulerSpecBuilder(this, item);
                        
            }

            SchedulerNestedImpl() {
                this.builder = new SchedulerSpecBuilder(this);
                        
            }

            public N and() {
                return (N) StressChaosSpecFluentImpl.this.withScheduler(builder.build());
            }

            public N endScheduler() {
                return and();
            }
    }


    public class SelectorNestedImpl<N> extends SelectorSpecFluentImpl<StressChaosSpecFluent.SelectorNested<N>> implements StressChaosSpecFluent.SelectorNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final SelectorSpecBuilder builder;

            SelectorNestedImpl(SelectorSpec item) {
                this.builder = new SelectorSpecBuilder(this, item);
                        
            }

            SelectorNestedImpl() {
                this.builder = new SelectorSpecBuilder(this);
                        
            }

            public N and() {
                return (N) StressChaosSpecFluentImpl.this.withSelector(builder.build());
            }

            public N endSelector() {
                return and();
            }
    }


    public class StressorsNestedImpl<N> extends StressorsFluentImpl<StressChaosSpecFluent.StressorsNested<N>> implements StressChaosSpecFluent.StressorsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final StressorsBuilder builder;

            StressorsNestedImpl(Stressors item) {
                this.builder = new StressorsBuilder(this, item);
                        
            }

            StressorsNestedImpl() {
                this.builder = new StressorsBuilder(this);
                        
            }

            public N and() {
                return (N) StressChaosSpecFluentImpl.this.withStressors(builder.build());
            }

            public N endStressors() {
                return and();
            }
    }


}

==> chaosmesh-model-5.3.2-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/StressChaosSpecFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.StringBuffer;
import java.lang.Object;

public class StressChaosSpecFluentImpl<A extends StressChaosSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements StressChaosSpecFluent<A> {

    private String containerName;
    private String duration;
    private String mode;
    private SchedulerSpecBuilder scheduler;
    private SelectorSpecBuilder selector;
    private String stressngStressors;
    private StressorsBuilder stressors;
    private String value;

    public StressChaosSpecFluentImpl() {
    }

    public StressChaosSpecFluentImpl(StressChaosSpec instance) {
        this.withContainerName(instance.getContainerName()); 
        this.withDuration(instance.getDuration()); 
        this.withMode(instance.getMode()); 
        this.withScheduler(instance.getScheduler()); 
        this.withSelector(instance.getSelector()); 
        this.withStressngStressors(instance.getStressngStressors()); 
        this.withStressors(instance.getStressors()); 
        this.withValue(instance.getValue()); 
    }

    public String getContainerName() {
        return this.containerName;
    }

    public A withContainerName(String containerName) {
        this.containerName=containerName; return (A) this;
    }

    public Boolean hasContainerName() {
        return this.containerName != null;
    }

    public A withNewContainerName(StringBuilder arg1) {
        return (A)withContainerName(new String(arg1));
    }

    public A withNewContainerName(int[] arg1,int arg2,int arg3) {
        return (A)withContainerName(new String(arg1, arg2, arg3));
    }

    public A withNewContainerName(char[] arg1) {
        return (A)withContainerName(new String(arg1));
    }

    public A withNewContainerName(StringBuffer arg1) {
        return (A)withContainerName(new String(arg1));
    }

    public A withNewContainerName(byte[] arg1,int arg2) {
        return (A)withContainerName(new String(arg1, arg2));
    }

    public A withNewContainerName(byte[] arg1) {
        return (A)withContainerName(new String(arg1));
    }

    public A withNewContainerName(char[] arg1,int arg2,int arg3) {
        return (A)withContainerName(new String(arg1, arg2, arg3));
    }

    public A withNewContainerName(byte[] arg1,int arg2,int arg3) {
        return (A)withContainerName(new String(arg1, arg2, arg3));
    }

    public A withNewContainerName(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withContainerName(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewContainerName(String arg1) {
        return (A)withContainerName(new String(arg1));
    }

    public String getDuration() {
        return this.duration;
    }

    public A withDuration(String duration) {
        this.duration=duration; return (A) this;
    }

    public Boolean hasDuration() {
        return this.duration != null;
    }

    public A withNewDuration(StringBuilder arg1) {
        return (A)withDuration(new String(arg1));
    }

    public A withNewDuration(int[] arg1,int arg2,int arg3) {
        return (A)withDuration(new String(arg1, arg2, arg3));
    }

    public A withNewDuration(char[] arg1) {
        return (A)withDuration(new String(arg1));
    }

    public A withNewDuration(StringBuffer arg1) {
        return (A)withDuration(new String(arg1));
    }

    public A withNewDuration(byte[] arg1,int arg2) {
        return (A)withDuration(new String(arg1, arg2));
    }

    public A withNewDuration(byte[] arg1) {
        return (A)withDuration(new String(arg1));
    }

    public A withNewDuration(char[] arg1,int arg2,int arg3) {
        return (A)withDuration(new String(arg1, arg2, arg3));
    }

    public A withNewDuration(byte[] arg1,int arg2,int arg3) {
        return (A)withDuration(new String(arg1, arg2, arg3));
    }

    public A withNewDuration(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withDuration(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewDuration(String arg1) {
        return (A)withDuration(new String(arg1));
    }

    public String getMode() {
        return this.mode;
    }

    public A withMode(String mode) {
        this.mode=mode; return (A) this;
    }

    public Boolean hasMode() {
        return this.mode != null;
    }

    public A withNewMode(StringBuilder arg1) {
        return (A)withMode(new String(arg1));
    }

    public A withNewMode(int[] arg1,int arg2,int arg3) {
        return (A)withMode(new String(arg1, arg2, arg3));
    }

    public A withNewMode(char[] arg1) {
        return (A)withMode(new String(arg1));
    }

    public A withNewMode(StringBuffer arg1) {
        return (A)withMode(new String(arg1));
    }

    public A withNewMode(byte[] arg1,int arg2) {
        return (A)withMode(new String(arg1, arg2));
    }

    public A withNewMode(byte[] arg1) {
        return (A)withMode(new String(arg1));
    }

    public A withNewMode(char[] arg1,int arg2,int arg3) {
        return (A)withMode(new String(arg1, arg2, arg3));
    }

    public A withNewMode(byte[] arg1,int arg2,int arg3) {
        return (A)withMode(new String(arg1, arg2, arg3));
    }

    public A withNewMode(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withMode(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewMode(String arg1) {
        return (A)withMode(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildScheduler instead.
 * @return The buildable object.
 */
@Deprecated public SchedulerSpec getScheduler() {
        return this.scheduler!=null?this.scheduler.build():null;
    }

    public SchedulerSpec buildScheduler() {
        return this.scheduler!=null?this.scheduler.build():null;
    }

    public A withScheduler(SchedulerSpec scheduler) {
        _visitables.get("scheduler").remove(this.scheduler);
        if (scheduler!=null){ this.scheduler= new SchedulerSpecBuilder(scheduler); _visitables.get("scheduler").add(this.scheduler);} return (A) this;
    }

    public Boolean hasScheduler() {
        return this.scheduler != null;
    }

    public A withNewScheduler(String cron) {
        return (A)withScheduler(new SchedulerSpec(cron));
    }

    public io.fabric8.chaosmesh.v1alpha1.StressChaosSpecFluent.SchedulerNested<A> withNewScheduler() {
        return new SchedulerNestedImpl();
    }

    public io.fabric8.chaosmesh.v1alpha1.StressChaosSpecFluent.SchedulerNested<A> withNewSchedulerLike(SchedulerSpec item) {
        return new SchedulerNestedImpl(item);
    }

    public io.fabric8.chaosmesh.v1alpha1.StressChaosSpecFluent.SchedulerNested<A> editScheduler() {
        return withNewSchedulerLike(getScheduler());
    }

    public io.fabric8.chaosmesh.v1alpha1.StressChaosSpecFluent.SchedulerNested<A> editOrNewScheduler() {
        return withNewSchedulerLike(getScheduler() != null ? getScheduler(): new SchedulerSpecBuilder().build());
    }

    public io.fabric8.chaosmesh.v1alpha1.StressChaosSpecFluent.SchedulerNested<A> editOrNewSchedulerLike(SchedulerSpec item) {
        return withNewSchedulerLike(getScheduler() != null ? getScheduler(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSelector instead.
 * @return The buildable object.
 */
@Deprecated public SelectorSpec getSelector() {
        return this.selector!=null?this.selector.build():null;
    }

    public SelectorSpec buildSelector() {
        return this.selector!=null?this.selector.build():null;
    }

    public A withSelector(SelectorSpec selector) {
        _visitables.get("selector").remove(this.selector);
        if (selector!=null){ this.selector= new SelectorSpecBuilder(selector); _visitables.get("selector").add(this.selector);} return (A) this;
    }

    public Boolean hasSelector() {
        return this.selector != null;
    }

    public io.fabric8.chaosmesh.v1alpha1.StressChaosSpecFluent.SelectorNested<A> withNewSelector() {
        return new SelectorNestedImpl();
    }

    public io.fabric8.chaosmesh.v1alpha1.StressChaosSpecFluent.SelectorNested<A> withNewSelectorLike(SelectorSpec item) {
        return new SelectorNestedImpl(item);
    }

    public io.fabric8.chaosmesh.v1alpha1.StressChaosSpecFluent.SelectorNested<A> editSelector() {
        return withNewSelectorLike(getSelector());
    }

    public io.fabric8.chaosmesh.v1alpha1.StressChaosSpecFluent.SelectorNested<A> editOrNewSelector() {
        return withNewSelectorLike(getSelector() != null ? getSelector(): new SelectorSpecBuilder().build());
    }

    public io.fabric8.chaosmesh.v1alpha1.StressChaosSpecFluent.SelectorNested<A> editOrNewSelectorLike(SelectorSpec item) {
        return withNewSelectorLike(getSelector() != null ? getSelector(): item);
    }

    public String getStressngStressors() {
        return this.stressngStressors;
    }

    public A withStressngStressors(String stressngStressors) {
        this.stressngStressors=stressngStressors; return (A) this;
    }

    public Boolean hasStressngStressors() {
        return this.stressngStressors != null;
    }

    public A withNewStressngStressors(StringBuilder arg1) {
        return (A)withStressngStressors(new String(arg1));
    }

    public A withNewStressngStressors(int[] arg1,int arg2,int arg3) {
        return (A)withStressngStressors(new String(arg1, arg2, arg3));
    }

    public A withNewStressngStressors(char[] arg1) {
        return (A)withStressngStressors(new String(arg1));
    }

    public A withNewStressngStressors(StringBuffer arg1) {
        return (A)withStressngStressors(new String(arg1));
    }

    public A withNewStressngStressors(byte[] arg1,int arg2) {
        return (A)withStressngStressors(new String(arg1, arg2));
    }

    public A withNewStressngStressors(byte[] arg1) {
        return (A)withStressngStressors(new String(arg1));
    }

    public A withNewStressngStressors(char[] arg1,int arg2,int arg3) {
        return (A)withStressngStressors(new String(arg1, arg2, arg3));
    }

    public A withNewStressngStressors(byte[] arg1,int arg2,int arg3) {
        return (A)withStressngStressors(new String(arg1, arg2, arg3));
    }

    public A withNewStressngStressors(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withStressngStressors(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewStressngStressors(String arg1) {
        return (A)withStressngStressors(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildStressors instead.
 * @return The buildable object.
 */
@Deprecated public Stressors getStressors() {
        return this.stressors!=null?this.stressors.build():null;
    }

    public Stressors buildStressors() {
        return this.stressors!=null?this.stressors.build():null;
    }

    public A withStressors(Stressors stressors) {
        _visitables.get("stressors").remove(this.stressors);
        if (stressors!=null){ this.stressors= new StressorsBuilder(stressors); _visitables.get("stressors").add(this.stressors);} return (A) this;
    }

    public Boolean hasStressors() {
        return this.stressors != null;
    }

    public io.fabric8.chaosmesh.v1alpha1.StressChaosSpecFluent.StressorsNested<A> withNewStressors() {
        return new StressorsNestedImpl();
    }

    public io.fabric8.chaosmesh.v1alpha1.StressChaosSpecFluent.StressorsNested<A> withNewStressorsLike(Stressors item) {
        return new StressorsNestedImpl(item);
    }

    public io.fabric8.chaosmesh.v1alpha1.StressChaosSpecFluent.StressorsNested<A> editStressors() {
        return withNewStressorsLike(getStressors());
    }

    public io.fabric8.chaosmesh.v1alpha1.StressChaosSpecFluent.StressorsNested<A> editOrNewStressors() {
        return withNewStressorsLike(getStressors() != null ? getStressors(): new StressorsBuilder().build());
    }

    public io.fabric8.chaosmesh.v1alpha1.StressChaosSpecFluent.StressorsNested<A> editOrNewStressorsLike(Stressors item) {
        return withNewStressorsLike(getStressors() != null ? getStressors(): item);
    }

    public String getValue() {
        return this.value;
    }

    public A withValue(String value) {
        this.value=value; return (A) this;
    }

    public Boolean hasValue() {
        return this.value != null;
    }

    public A withNewValue(StringBuilder arg1) {
        return (A)withValue(new String(arg1));
    }

    public A withNewValue(int[] arg1,int arg2,int arg3) {
        return (A)withValue(new String(arg1, arg2, arg3));
    }

    public A withNewValue(char[] arg1) {
        return (A)withValue(new String(arg1));
    }

    public A withNewValue(StringBuffer arg1) {
        return (A)withValue(new String(arg1));
    }

    public A withNewValue(byte[] arg1,int arg2) {
        return (A)withValue(new String(arg1, arg2));
    }

    public A withNewValue(byte[] arg1) {
        return (A)withValue(new String(arg1));
    }

    public A withNewValue(char[] arg1,int arg2,int arg3) {
        return (A)withValue(new String(arg1, arg2, arg3));
    }

    public A withNewValue(byte[] arg1,int arg2,int arg3) {
        return (A)withValue(new String(arg1, arg2, arg3));
    }

    public A withNewValue(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withValue(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewValue(String arg1) {
        return (A)withValue(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        StressChaosSpecFluentImpl that = (StressChaosSpecFluentImpl) o;
        if (containerName != null ? !containerName.equals(that.containerName) :that.containerName != null) return false;
        if (duration != null ? !duration.equals(that.duration) :that.duration != null) return false;
        if (mode != null ? !mode.equals(that.mode) :that.mode != null) return false;
        if (scheduler != null ? !scheduler.equals(that.scheduler) :that.scheduler != null) return false;
        if (selector != null ? !selector.equals(that.selector) :that.selector != null) return false;
        if (stressngStressors != null ? !stressngStressors.equals(that.stressngStressors) :that.stressngStressors != null) return false;
        if (stressors != null ? !stressors.equals(that.stressors) :that.stressors != null) return false;
        if (value != null ? !value.equals(that.value) :that.value != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(containerName,  duration,  mode,  scheduler,  selector,  stressngStressors,  stressors,  value,  super.hashCode());
    }

    public class SchedulerNestedImpl<N> extends SchedulerSpecFluentImpl<io.fabric8.chaosmesh.v1alpha1.StressChaosSpecFluent.SchedulerNested<N>> implements io.fabric8.chaosmesh.v1alpha1.StressChaosSpecFluent.SchedulerNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final SchedulerSpecBuilder builder;

            SchedulerNestedImpl(SchedulerSpec item) {
                this.builder = new SchedulerSpecBuilder(this, item);
                        
            }

            SchedulerNestedImpl() {
                this.builder = new SchedulerSpecBuilder(this);
                        
            }

            public N and() {
                return (N) StressChaosSpecFluentImpl.this.withScheduler(builder.build());
            }

            public N endScheduler() {
                return and();
            }
    }


    public class SelectorNestedImpl<N> extends SelectorSpecFluentImpl<io.fabric8.chaosmesh.v1alpha1.StressChaosSpecFluent.SelectorNested<N>> implements io.fabric8.chaosmesh.v1alpha1.StressChaosSpecFluent.SelectorNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final SelectorSpecBuilder builder;

            SelectorNestedImpl(SelectorSpec item) {
                this.builder = new SelectorSpecBuilder(this, item);
                        
            }

            SelectorNestedImpl() {
                this.builder = new SelectorSpecBuilder(this);
                        
            }

            public N and() {
                return (N) StressChaosSpecFluentImpl.this.withSelector(builder.build());
            }

            public N endSelector() {
                return and();
            }
    }


    public class StressorsNestedImpl<N> extends StressorsFluentImpl<io.fabric8.chaosmesh.v1alpha1.StressChaosSpecFluent.StressorsNested<N>> implements io.fabric8.chaosmesh.v1alpha1.StressChaosSpecFluent.StressorsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final StressorsBuilder builder;

            StressorsNestedImpl(Stressors item) {
                this.builder = new StressorsBuilder(this, item);
                        
            }

            StressorsNestedImpl() {
                this.builder = new StressorsBuilder(this);
                        
            }

            public N and() {
                return (N) StressChaosSpecFluentImpl.this.withStressors(builder.build());
            }

            public N endStressors() {
                return and();
            }
    }


}
